@@ -237,7 +237,7 @@ class BeaconAPI(object):
     def put(self, _name, **args):      return self.do('put', _name, args)
     def delete(self, _name, **args):   return self.do('delete', _name, args)
 
-    def do_async(self, method, _name, args, use_tqdm=False, update_delay=1):
+    def do_async(self, method, _name, args, use_tqdm=False, update_delay=1, status_retries=5):
         """
         execute API call which is expected to return a polling object for progress
         Args:
@@ -246,6 +246,7 @@ class BeaconAPI(object):
             args:   dictionary of arguments
             use_tqdm: show progress bar using TQDM. Recommended value: os.isatty(sys.stdin.fileno())
             update_delay: number of seconds to wait before asking for progress
+            status_retries: if status call fails with non-200, retry that many times
         """
         status = self.do(method, _name, args)
         ident = status['ident']
@@ -257,7 +258,16 @@ class BeaconAPI(object):
 
         try:
             while 1:
-                progress = self.get('status', id=ident)
+                for retry in range(status_retries):
+                    try:
+                        progress = self.get('status', id=ident)
+                    except BeaconAPIException as e:
+                        if retry == status_retries-1:
+                            raise
+                        time.sleep(1+retry/2.0)
+                        continue
+
+
                 if progress['status'] == 'finished':
                     return progress['extra']
                 elif progress['status'] == 'cancelled':
